@@ -58,6 +58,14 @@ class TestMessagePackRPC(unittest.TestCase):
             sleep(3)
             return 'finish!'
 
+        def async_result(self):
+            ar = msgpackrpc.server.AsyncResult()
+            def do_async():
+                sleep(2)
+                ar.set_result("You are async!")
+            threading.Thread(target=do_async).start()
+            return ar
+
     def setUp(self):
         self._address = msgpackrpc.Address('localhost', helper.unused_port())
 
@@ -146,6 +154,10 @@ class TestMessagePackRPC(unittest.TestCase):
             message = e.args[0]
             self.assertEqual(message, "'unknown' method not found", "Error message mismatched")
 
+    def test_async_result(self):
+        client = self.setup_env();
+        self.assertEqual(client.call('async_result'), "You are async!")
+
     def test_connect_failed(self):
         client = self.setup_env();
         client = msgpackrpc.Client(msgpackrpc.Address('localhost', self._address.port - 10), unpack_encoding='utf-8')
